@@ -92,6 +92,18 @@ func TestWriteANSIColors(t *testing.T) {
 			Colors:   &Color{Foreground: "black", Background: "white"},
 			Parent:   &Color{Foreground: "yellow", Background: "red"},
 		},
+		{
+			Case:     "Inherit no parent foreground",
+			Input:    "hello <inherit>world</>",
+			Expected: "\x1b[47m\x1b[30mhello \x1b[0m\x1b[47;49m\x1b[7mworld\x1b[0m",
+			Colors:   &Color{Foreground: "black", Background: "white"},
+		},
+		{
+			Case:     "Inherit no parent background",
+			Input:    "hello <,inherit>world</>",
+			Expected: "\x1b[47m\x1b[30mhello \x1b[0m\x1b[30mworld\x1b[0m",
+			Colors:   &Color{Foreground: "black", Background: "white"},
+		},
 		{
 			Case:     "Inline override",
 			Input:    "hello, <red>world</>, rabbit",
